@@ -23,9 +23,9 @@
 
 using namespace NoteShared;
 
-
 NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     : QDialog(parent)
+    , m_buttons(new QButtonGroup(this))
 {
     setWindowTitle(caption);
     auto mainLayout = new QVBoxLayout(this);
@@ -38,7 +38,6 @@ NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     auto pageVBoxLayout = new QVBoxLayout(page);
     pageVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
-    m_buttons = new QButtonGroup(this);
     auto group = new QGroupBox(i18n("Scheduled Alarm"), page);
     pageVBoxLayout->addWidget(group);
     auto layout = new QVBoxLayout;
@@ -64,7 +63,7 @@ NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     layout->addWidget(at);
     m_buttons->addButton(label_at, 1);
 
-    connect(m_buttons, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &NoteAlarmDialog::slotButtonChanged);
+    connect(m_buttons, &QButtonGroup::buttonClicked, this, &NoteAlarmDialog::slotButtonChanged);
     connect(okButton, &QPushButton::clicked, this, &NoteAlarmDialog::accept);
     m_buttons->button(0)->setChecked(true);
     slotButtonChanged(m_buttons->checkedButton());
@@ -108,6 +107,6 @@ QDateTime NoteAlarmDialog::alarm() const
     if (m_buttons->checkedId() == 1) {
         return QDateTime(m_atDate->date(), m_atTime->time());
     } else {
-        return QDateTime();
+        return {};
     }
 }
