@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -45,9 +45,7 @@ KNotePrintSelectThemeDialog::KNotePrintSelectThemeDialog(QWidget *parent)
     mainLayout->addWidget(buttonBox);
 }
 
-KNotePrintSelectThemeDialog::~KNotePrintSelectThemeDialog()
-{
-}
+KNotePrintSelectThemeDialog::~KNotePrintSelectThemeDialog() = default;
 
 QString KNotePrintSelectThemeDialog::selectedTheme() const
 {
